==> css-pro-layout-1.0.0.tgz: package/README.md <==
# CSS Pro Layout

CSS library for building responsive and customizable page layouts

[![npm][version]][npm-url]
[![License][license]][npm-url]

[npm-url]: https://www.npmjs.com/package/css-pro-layout
[version]: https://img.shields.io/npm/v/css-pro-layout.svg?style=flat-square
[license]: https://img.shields.io/github/license/azouaoui-med/css-pro-layout?style=flat-square

<hr>

## Documentation

For full documentation, visit [https://azouaoui-med.github.io/css-pro-layout](https://azouaoui-med.github.io/css-pro-layout)

## Getting started

You can install css pro layout with NPM or Yarn

### NPM

```shell
npm install css-pro-layout
```

### Yarn

```shell
yarn add css-pro-layout
```

Import `css-pro-layout.css` into your module

```js
import 'css-pro-layout/dist/css/css-pro-layout.css';
```

### CDN

You can also use the CDN link from [unpkg.com](https://unpkg.com)

```html
<link href="https://unpkg.com/css-pro-layout/dist/css/css-pro-layout.min.css" rel="stylesheet" />
```

### Basic Usage

```html
<div class="layout">
  <header class="header">Header</header>
  <main class="content">Content</main>
  <footer class="footer">Footer</footer>
</div>
```

Please refer to the [Examples page](https://azouaoui-med.github.io/docs/getting-started/examples) for more use cases.

## Demos

- [**Vanilla js** | Sandbox](https://codesandbox.io/s/css-pro-layout-vanilla-js-mpqds?file=/index.html)
- [**React js** | Sandbox](https://codesandbox.io/s/css-pro-layout-react-js-sgl3q?file=/src/App.js)
- [**vue js** | Sandbox](https://codesandbox.io/s/css-pro-layout-vue-hmdjp)
- [**Angular** | Sandbox](https://codesandbox.io/s/css-pro-layout-angular-9vkt2)

## Change Log

This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html). Every release, along with the migration instructions, is documented on the GitHub [Releases](https://github.com/azouaoui-med/css-pro-layout/releases) page.

## License

MIT © [Mohamed Azouaoui](https://azouaoui.netlify.com)

==> css-pro-layout-1.1.0.tgz: package/README.md <==
# CSS Pro Layout

CSS library for building responsive and customizable page layouts

[![npm][version]][npm-url]
[![License][license]][npm-url]

[npm-url]: https://www.npmjs.com/package/css-pro-layout
[version]: https://img.shields.io/npm/v/css-pro-layout.svg?style=flat-square
[license]: https://img.shields.io/github/license/azouaoui-med/css-pro-layout?style=flat-square

<hr>

## Documentation

For full documentation, visit [https://azouaoui-med.github.io/css-pro-layout](https://azouaoui-med.github.io/css-pro-layout)

## Getting started

You can install css pro layout with NPM or Yarn

### NPM

```shell
npm install css-pro-layout
```

### Yarn

```shell
yarn add css-pro-layout
```

Import `css-pro-layout.css` into your module

```js
import 'css-pro-layout/dist/css/css-pro-layout.css';
```

### CDN

You can also use the CDN link from [unpkg.com](https://unpkg.com)

```html
<link href="https://unpkg.com/css-pro-layout/dist/css/css-pro-layout.min.css" rel="stylesheet" />
```

### Basic Usage

```html
<div class="layout">
  <header class="header">Header</header>
  <main class="content">Content</main>
  <footer class="footer">Footer</footer>
</div>
```

Please refer to the [Examples page](https://azouaoui-med.github.io/css-pro-layout/docs/getting-started/examples) for more use cases.

## Demos

- [**Vanilla js** | Sandbox](https://codesandbox.io/s/css-pro-layout-vanilla-js-mpqds?file=/index.html)
- [**React js** | Sandbox](https://codesandbox.io/s/css-pro-layout-react-js-sgl3q?file=/src/App.js)
- [**vue js** | Sandbox](https://codesandbox.io/s/css-pro-layout-vue-hmdjp)
- [**Angular** | Sandbox](https://codesandbox.io/s/css-pro-layout-angular-9vkt2)

## Change Log

This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html). Every release, along with the migration instructions, is documented on the GitHub [Releases](https://github.com/azouaoui-med/css-pro-layout/releases) page.

## License

MIT © [Mohamed Azouaoui](https://azouaoui.netlify.com)
